@@ -13,6 +13,7 @@ from aqueduct.artifacts.transform import to_artifact_class
 from aqueduct.constants.enums import (
     ArtifactType,
     CheckSeverity,
+    CustomizableResourceType,
     ExecutionMode,
     FunctionGranularity,
     FunctionType,
@@ -330,12 +331,6 @@ def _convert_input_arguments_to_parameters(
     return artifacts
 
 
-# Supported resource configuration keys, supplied in the `resources` field of the decorators.
-NUM_CPUS_KEY = "num_cpus"
-MEMORY_KEY = "memory"
-GPU_RESOURCE_NAME_KEY = "gpu_resource_name"
-
-
 def _convert_memory_string_to_mbs(memory_str: str) -> int:
     """Converts a memory string supplied by the user into the equivalent number in MBs.
 
@@ -392,9 +387,10 @@ def _update_operator_spec_with_resources(
         if not isinstance(resources, Dict) or any(not isinstance(k, str) for k in resources):
             raise InvalidUserArgumentException("`resources` must be a dictionary with string keys.")
 
-        num_cpus = resources.get(NUM_CPUS_KEY)
-        memory = resources.get(MEMORY_KEY)
-        gpu_resource_name = resources.get(GPU_RESOURCE_NAME_KEY)
+        num_cpus = resources.get(CustomizableResourceType.NUM_CPUS)
+        memory = resources.get(CustomizableResourceType.MEMORY)
+        gpu_resource_name = resources.get(CustomizableResourceType.GPU_RESOURCE_NAME)
+        cuda_version = resources.get(CustomizableResourceType.CUDA_VERSION)
 
         if num_cpus is not None and (not isinstance(num_cpus, int) or num_cpus < 0):
             raise InvalidUserArgumentException(
@@ -423,6 +419,14 @@ def _update_operator_spec_with_resources(
         if gpu_resource_name is not None and (not isinstance(gpu_resource_name, str)):
             raise InvalidUserArgumentException("`gpu_resource_name` value must be set to a string.")
 
+        if cuda_version is not None and (not isinstance(cuda_version, str)):
+            raise InvalidUserArgumentException("`cuda_version` value must be set to a string.")
+
+        if cuda_version is not None and gpu_resource_name is None:
+            raise InvalidUserArgumentException(
+                "`cuda_version` can only be set if a `gpu_resource_name` is specified."
+            )
+
         spec.resources = ResourceConfig(
             num_cpus=num_cpus, memory_mb=memory, gpu_resource_name=gpu_resource_name
         )
@@ -492,6 +496,11 @@ def op(
             "gpu_resource_name" (str):
                 Name of the gpu resource to use (only applicable for Kubernetes engine).
 
+                For example, the following value is valid: "nvidia.com/gpu".
+            "cuda_version" (str):
+                Version of CUDA to use with GPU (only applicable for Kubernetes engine). The currently supported
+                values are "11.4.1" and "11.8.0".
+
     Examples:
         The op name is inferred from the function name. The description is pulled from the function
         docstring or can be explicitly set in the decorator.
@@ -536,7 +545,7 @@ def op(
             description = func.__doc__ or ""
 
         def _wrapped_util(
-            *input_artifacts: BaseArtifact, execution_mode: ExecutionMode
+            *input_artifacts: BaseArtifact, execution_mode: Optional[ExecutionMode] = None
         ) -> Union[BaseArtifact, List[BaseArtifact]]:
             """
             Creates the following files in the zipped folder structure:
@@ -549,6 +558,11 @@ def op(
             assert isinstance(name, str)
             assert isinstance(description, str)
 
+            if execution_mode == None:
+                execution_mode = _get_global_execution_mode()
+
+            assert isinstance(execution_mode, ExecutionMode)
+
             artifacts = _convert_input_arguments_to_parameters(
                 *input_artifacts,
                 op_name=name,
@@ -583,7 +597,7 @@ def op(
             )
 
         def wrapped(*input_artifacts: BaseArtifact) -> Union[BaseArtifact, List[BaseArtifact]]:
-            return _wrapped_util(*input_artifacts, execution_mode=ExecutionMode.EAGER)
+            return _wrapped_util(*input_artifacts)
 
         # Enable the .local(*args) attribute, which calls the original function with the raw inputs.
         def local_func(*inputs: Any) -> Any:
@@ -597,9 +611,6 @@ def op(
 
         setattr(wrapped, "lazy", lazy_mode)
 
-        if globals.__GLOBAL_CONFIG__.lazy:
-            return lazy_mode
-
         return wrapped
 
     if callable(name):
@@ -698,7 +709,7 @@ def metric(
             description = func.__doc__ or ""
 
         def _wrapped_util(
-            *input_artifacts: BaseArtifact, execution_mode: ExecutionMode
+            *input_artifacts: BaseArtifact, execution_mode: Optional[ExecutionMode] = None
         ) -> NumericArtifact:
             """
             Creates the following files in the zipped folder structure:
@@ -711,6 +722,11 @@ def metric(
             assert isinstance(name, str)
             assert isinstance(description, str)
 
+            if execution_mode == None:
+                execution_mode = _get_global_execution_mode()
+
+            assert isinstance(execution_mode, ExecutionMode)
+
             if len(input_artifacts) == 0:
                 raise InvalidUserArgumentException(
                     "Metrics must have an input. Did you forget to call this metric on an artifact?"
@@ -762,7 +778,7 @@ def metric(
         def wrapped(
             *input_artifacts: BaseArtifact,
         ) -> NumericArtifact:
-            return _wrapped_util(*input_artifacts, execution_mode=ExecutionMode.EAGER)
+            return _wrapped_util(*input_artifacts)
 
         # Enable the .local(*args) attribute, which calls the original function with the raw inputs.
         def local_func(*inputs: Any) -> Number:
@@ -776,9 +792,6 @@ def metric(
 
         setattr(wrapped, "lazy", lazy_mode)
 
-        if globals.__GLOBAL_CONFIG__.lazy:
-            return lazy_mode
-
         return wrapped
 
     if callable(name):
@@ -883,7 +896,7 @@ def check(
             description = func.__doc__ or ""
 
         def _wrapped_util(
-            *input_artifacts: BaseArtifact, execution_mode: ExecutionMode
+            *input_artifacts: BaseArtifact, execution_mode: Optional[ExecutionMode] = None
         ) -> BoolArtifact:
             """
             Creates the following files in the zipped folder structure:
@@ -896,6 +909,11 @@ def check(
             assert isinstance(name, str)
             assert isinstance(description, str)
 
+            if execution_mode == None:
+                execution_mode = _get_global_execution_mode()
+
+            assert isinstance(execution_mode, ExecutionMode)
+
             if len(input_artifacts) == 0:
                 raise InvalidUserArgumentException(
                     "Check must have an input. Did you forget to call this check on an artifact?"
@@ -945,7 +963,7 @@ def check(
         def wrapped(
             *input_artifacts: BaseArtifact,
         ) -> BoolArtifact:
-            return _wrapped_util(*input_artifacts, execution_mode=ExecutionMode.EAGER)
+            return _wrapped_util(*input_artifacts)
 
         # Enable the .local(*args) attribute, which calls the original function with the raw inputs.
         def local_func(*inputs: Any) -> Union[bool, np.bool_]:
@@ -959,8 +977,6 @@ def check(
 
         setattr(wrapped, "lazy", lazy_mode)
 
-        if globals.__GLOBAL_CONFIG__.lazy:
-            return lazy_mode
         return wrapped
 
     if callable(name):
@@ -1017,3 +1033,10 @@ def to_operator(
         ),
     )
     return func_op(func)
+
+
+def _get_global_execution_mode() -> ExecutionMode:
+    if globals.__GLOBAL_CONFIG__.lazy:
+        return ExecutionMode.LAZY
+    else:
+        return ExecutionMode.EAGER
