@@ -1,12 +1,14 @@
 from aqueduct.integrations.connect_config import (
     AthenaConfig,
     BigQueryConfig,
+    GCSConfig,
     IntegrationConfig,
     MongoDBConfig,
     MySQLConfig,
     PostgresConfig,
     S3Config,
     SnowflakeConfig,
+    SparkConfig,
     SQLiteConfig,
     SqlServerConfig,
 )
