@@ -3,12 +3,12 @@ from typing import Any, Dict, List, Optional
 
 from aqueduct.artifacts import preview as artifact_utils
 from aqueduct.artifacts.base_artifact import BaseArtifact
-from aqueduct.artifacts.save import save_artifact
 from aqueduct.artifacts.table_artifact import TableArtifact
 from aqueduct.constants.enums import ArtifactType, ExecutionMode, LoadUpdateMode
 from aqueduct.error import InvalidUserArgumentException
+from aqueduct.integrations.naming import _resolve_op_and_artifact_name_for_extract
+from aqueduct.integrations.save import _save_artifact
 from aqueduct.integrations.sql_integration import find_parameter_artifacts, find_parameter_names
-from aqueduct.logger import logger
 from aqueduct.models.artifact import ArtifactMetadata
 from aqueduct.models.dag import DAG
 from aqueduct.models.integration import Integration, IntegrationInfo
@@ -18,10 +18,9 @@ from aqueduct.models.operators import (
     Operator,
     OperatorSpec,
     RelationalDBLoadParams,
-    SaveConfig,
 )
 from aqueduct.utils.dag_deltas import AddOrReplaceOperatorDelta, apply_deltas_to_dag
-from aqueduct.utils.utils import artifact_name_from_op_name, generate_uuid
+from aqueduct.utils.utils import generate_uuid
 
 from aqueduct import globals
 
@@ -39,6 +38,7 @@ class MongoDBCollectionIntegration(Integration):
         self,
         *args: List[Any],
         name: Optional[str] = None,
+        output: Optional[str] = None,
         description: str = "",
         lazy: bool = False,
         **kwargs: Dict[str, Any],
@@ -55,10 +55,18 @@ class MongoDBCollectionIntegration(Integration):
                 Name of the query.
             description:
                 Description of the query.
+            output:
+                Name to assign the output artifact. If not set, the default naming scheme will be used.
             lazy:
                 Whether to run this operator lazily. See https://docs.aqueducthq.com/operators/lazy-vs.-eager-execution .
         """
-        op_name = name or self._dag.get_unclaimed_op_name(prefix="%s query" % self.name())
+        op_name, artifact_name = _resolve_op_and_artifact_name_for_extract(
+            dag=self._dag,
+            op_name=name,
+            default_op_name="%s query" % self.name(),
+            artifact_name=output,
+        )
+
         if globals.__GLOBAL_CONFIG__.lazy:
             lazy = True
         execution_mode = ExecutionMode.EAGER if not lazy else ExecutionMode.LAZY
@@ -113,7 +121,7 @@ class MongoDBCollectionIntegration(Integration):
                     output_artifacts=[
                         ArtifactMetadata(
                             id=output_artf_id,
-                            name=artifact_name_from_op_name(op_name),
+                            name=artifact_name,
                             type=ArtifactType.TABLE,
                         ),
                     ],
@@ -130,16 +138,6 @@ class MongoDBCollectionIntegration(Integration):
             # We are in lazy mode.
             return TableArtifact(self._dag, output_artf_id)
 
-    def config(self, update_mode: LoadUpdateMode) -> SaveConfig:
-        """TODO(ENG-2035): Deprecated and will be removed."""
-        logger().warning(
-            "`integration.config()` is deprecated. Please use `integration.save()` directly instead."
-        )
-        return SaveConfig(
-            integration_info=self._metadata,
-            parameters=RelationalDBLoadParams(table=self._collection_name, update_mode=update_mode),
-        )
-
     def save(self, artifact: BaseArtifact, update_mode: LoadUpdateMode) -> None:
         """Registers a save operator of the given artifact, to be executed when it's computed in a published flow.
 
@@ -150,9 +148,8 @@ class MongoDBCollectionIntegration(Integration):
                 Defines the semantics of the save if a table already exists.
                 Options are "replace", "append" (row-wise), or "fail" (if table already exists).
         """
-        save_artifact(
+        _save_artifact(
             artifact.id(),
-            artifact.type(),
             self._dag,
             self._metadata,
             save_params=RelationalDBLoadParams(
@@ -188,16 +185,6 @@ class MongoDBIntegration(Integration):
         print("==================== MongoDB Integration  =============================")
         self._metadata.describe()
 
-    def config(self, collection: str, update_mode: LoadUpdateMode) -> SaveConfig:
-        """TODO(ENG-2035): Deprecated and will be removed."""
-        logger().warning(
-            "`integration.config()` is deprecated. Please use `integration.save()` directly instead."
-        )
-        return SaveConfig(
-            integration_info=self._metadata,
-            parameters=RelationalDBLoadParams(table=collection, update_mode=update_mode),
-        )
-
     def save(self, artifact: BaseArtifact, collection: str, update_mode: LoadUpdateMode) -> None:
         """Registers a save operator of the given artifact, to be executed when it's computed in a published flow.
 
@@ -210,9 +197,8 @@ class MongoDBIntegration(Integration):
                 Defines the semantics of the save if a collection already exists.
                 Options are "replace", "append" (row-wise), or "fail" (if table already exists).
         """
-        save_artifact(
+        _save_artifact(
             artifact.id(),
-            artifact.type(),
             self._dag,
             self._metadata,
             save_params=RelationalDBLoadParams(table=collection, update_mode=update_mode),
